==> v8.3.zip: ru_twords_ru_tw/bible/other/pillar.md <==
# столб, колонна

## Определение:

Столб — это вертикальная опора, служащая для поддержания крыши или какой-либо другой части строения. Синоним этого слова: “колонна”.

* Ветхозаветный герой Самсон сдвинул опорные столбы в филистимском храме, что привело к обрушению всего здания.
* Иногда столбы использовались как памятники или служили для обозначения какого-либо места, где когда-то произошло памятное событие.
* В библейские времена столбы высекались из цельного камня и использовались в качестве опоры для зданий.
* Древний памятник представлял собой огромный валун или столб с большим камнем наверху.
* Иногда столбом называлась статуя какого-либо божества. В отдельных случаях вместо слова “столб” в Библии употребляется словосочетание “высеченное изображение”, которое можно перевести как “статуя”.
* Столбом может назваться предмет или явление, имеющее схожую со столбом форму, например, “огненный столп” (столп огня, ведший израильтян по пустыне ночью) или “соляной столп” (в который превратилась жена Лота, когда обернулась, чтобы посмотреть на Содом).
* В зависимости от контекста слово “столб” может переводиться как “статуя”, “опора”, “памятник”.

(См. также: [основание](../other/foundation.md), [ложный бог](../kt/falsegod.md), [образ](../other/image.md))

## Ссылки на библейский текст:

* [4 Цар. 18:4-5](rc://*/tn/help/2ki/18/04)
* [Исх. 13:19-22](rc://*/tn/help/exo/13/19)
* [Исх. 33:7-9](rc://*/tn/help/exo/33/07)
* [Быт. 31:45-47](rc://*/tn/help/gen/31/45)
* [Притч. 9:1-2](rc://*/tn/help/pro/09/01)

## Данные о слове:

* Номера Стронга: H352, H547, H2106, H2553, H3730, H4552, H4676, H4678, H4690, H5324, H5333, H5982, H8490, G4769

==> v9.2.zip: ru_twords_ru_tw/bible/other/pillar.md <==
# столб, колонна, опора

## Определение:

Столб — это вертикальная конструкция, служащая для поддержания крыши или какой-либо другой части строения. Синоним этого слова: “колонна” или "опора".

* Ветхозаветный герой Самсон сдвинул опорные столбы в филистимском храме, что привело к обрушению всего здания. 
* Иногда столбы использовались как памятники или служили для обозначения какого-либо места, где когда-то произошло памятное событие.
* В библейские времена столбы высекались из цельного камня и использовались в качестве опоры для зданий.
* Древний памятник представлял собой огромный валун или столб с большим камнем наверху.
* Иногда столбом называлась статуя какого-либо божества. В отдельных случаях вместо слова “столб” в Библии употребляется словосочетание “высеченное изображение”, которое можно перевести как “статуя”.
* Столбом может назваться предмет или явление, имеющее схожую со столбом форму, например, “огненный столп” (столп огня, ведший израильтян по пустыне ночью) или “соляной столп” (в который превратилась жена Лота, когда обернулась, чтобы посмотреть на Содом).
* В зависимости от контекста слово “столб” может переводиться как “статуя”, “опора”, “памятник”.

(См. также: [основание](../other/foundation.md), [ложный бог](../kt/falsegod.md), [образ](../other/image.md))

## Ссылки на библейский текст:

* [4 Цар. 18:4-5](rc://ru/tn/help/2ki/18/04)
* [Исх. 13:19-22](rc://ru/tn/help/exo/13/19)
* [Исх. 33:7-9](rc://ru/tn/help/exo/33/07)
* [Быт. 31:45-47](rc://ru/tn/help/gen/31/45)
* [Притч. 9:1-2](rc://ru/tn/help/pro/09/01)

## Данные о слове:

* Номера Стронга: H352, H547, H2106, H2553, H3730, H4552, H4676, H4678, H4690, H5324, H5333, H5982, H8490, G4769
